# setup.py
# -*- coding: utf8 -*-
# vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4

"""Setuptools setup.py file for Robolock II."""

from setuptools import setup, find_packages
from setuptools.command.sdist import sdist
from setuptools.command.install import install

from tools import gen_json

try:
    import py2exe
    py2exe  # To make pyflakes happy.
except ImportError:
    pass


# This should probably be pulled from constants.py
# These two constants are used by darwin-py2app.sh.
VERSION_STR = "0.1"
NAME_STR = "robolock-II"


class NajaSdist(sdist):
    def run(self):
        gen_json.main()
        sdist.run(self)


class NajaInstall(install):
    def run(self):
        gen_json.main(update=False)
        install.run(self)


setup(
    name=NAME_STR,
    version=VERSION_STR,
    description="Robolock II - a puzzle game",

    author=(", ".join([
        "Simon Cross",
        "Neil Muller",
        "Adrianna Pińska",
        "Stefano Rivera",
        "David Sharpe",
        "Jeremy Thurgood",
    ])),
    author_email="ctpug@googlegroups.com",

    maintainer="Team Naja (CTPUG)",
    maintainer_email="ctpug@googlegroups.com",

    url="http://robolock.org/",
    download_url="http://ctpug.org.za/git/naja",

    license="MIT",

    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: MacOS X',
        'Environment :: Win32 (MS Windows)',
        'Environment :: X11 Applications',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: MacOS :: MacOS X',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Games/Entertainment',
    ],

    platforms=[
        'Linux',
        'Mac OS X',
        'Windows',
    ],

    # Dependencies
    install_requires=[
        'pygame',
    ],

    setup_requires=[
        'PyYAML',
    ],

    # Files
    packages=find_packages(),
    scripts=[
        'scripts/naja',
    ],

    cmdclass={
        'sdist': NajaSdist,
        'install': NajaInstall,
    },

    # py2exe
    windows=[{
        'script': 'scripts/naja',
        'icon_resources': [(0, "data/icons/robolock.ico")],
    }],
    app=['scripts/naja'],
    options={
        'py2exe': {
            'skip_archive': 1,
            'dist_dir': 'dist/naja-%s' % VERSION_STR,
            'packages': [
                'logging', 'encodings', 'naja',
            ],
            'includes': [
                'pygame',
            ],
            'excludes': [
                'numpy', 'pygame.sdlmain_osx', 'winreg', 'AppKit',
                'Foundation', 'Numeric', 'OpenGL.GL', '_scproxy',
                '_sysconfigdata', 'copyreg', 'dummy.Process', 'pkg_resources',
                'queue', 'win32evtlog', 'win32evtlogutil',
            ],
            'ignores': [
                # all database modules
                'pgdb', 'Sybase', 'adodbapi',
                'kinterbasdb', 'psycopg', 'psycopg2', 'pymssql',
                'sapdb', 'pysqlite2', 'sqlite', 'sqlite3',
                'MySQLdb', 'MySQLdb.connections',
                'MySQLdb.constants.CR', 'MySQLdb.constants.ER',
                # old datetime equivalents
                'DateTime', 'DateTime.ISO',
                'mx', 'mx.DateTime', 'mx.DateTime.ISO',
                # email modules
                'email.Generator', 'email.Iterators', 'email.Utils',
            ],
        },
        'py2app': {
            'app': ['run_game.py'],
            'argv_emulation': True,
            'iconfile': 'data/icons/robolock.icns',
            'packages': [
                'logging', 'encodings', 'pygame', 'naja', 'data',
            ],
            'excludes': ['numpy'],
        }},
    data_files=[
        # 'COPYRIGHT',
        'LICENSE.txt',
        'README.txt',
    ],
    include_package_data=True,
)
